@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import asyncio
 from typing import Any
-from unittest.mock import call, Mock
+from unittest.mock import AsyncMock, call, Mock
 
 import h11
 import pytest
@@ -18,13 +18,6 @@ from hypercorn.protocol.h11 import H2CProtocolRequiredError, H2ProtocolAssumedEr
 from hypercorn.protocol.http_stream import HTTPStream
 from hypercorn.typing import ConnectionState, Event as IOEvent
 
-try:
-    from unittest.mock import AsyncMock
-except ImportError:
-    # Python < 3.8
-    from mock import AsyncMock  # type: ignore
-
-
 BASIC_HEADERS = [("Host", "hypercorn"), ("Connection", "close")]
 
 
@@ -379,7 +372,7 @@ async def test_protocol_handle_h2c_upgrade(protocol: H11Protocol) -> None:
         (b"upgrade", b"h2c"),
         (b"http2-settings", b"abcd"),
     ]
-    assert exc_info.value.settings == "abcd"
+    assert exc_info.value.settings == b"abcd"
 
 
 @pytest.mark.asyncio
